betty.deriver module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.deriver module

Provide an API to derive information from ancestries, and create new entities or update existing ones.

class betty.deriver.Derivation

  Bases: `Enum`

  Derivation types.

  CREATE = 2

    The derivation created new data.

  NONE = 1

    No derivation took place.

  UPDATE = 3

    The derivation updated existing data.

final class betty.deriver.Deriver

  Bases: `object`

  Derive information from ancestries, and create new entities or update existing ones.

  __init__(ancestry: Ancestry, lifetime_threshold: int, event_types: PluginRepository[EventType], derivable_event_types: set[type[DerivableEventType]], *, localizer: Localizer)
  async derive() → None

    Derive additional data.